@@ -611,6 +611,103 @@ def new(output_file):
         click.echo(kacl_changelog_content)
 
 
+@cli.command("add-comments")
+@click.pass_context
+@click.option(
+    "--jira-username",
+    required=False,
+    type=str,
+    default=os.getenv(
+        "JIRA_USERNAME",
+        None,
+    ),
+    help="JIRA username. Will also look for JIRA_USERNAME environment variable.",
+)
+@click.option(
+    "--jira-password",
+    required=False,
+    type=str,
+    default=os.getenv(
+        "JIRA_PASSWORD",
+        None,
+    ),
+    help="JIRA password. Will also look for JIRA_PASSWORD environment variable.",
+)
+@click.option(
+    "--jira-host",
+    required=False,
+    type=str,
+    default=os.getenv(
+        "JIRA_HOST",
+        None,
+    ),
+    help="JIRA host. Will also look for JIRA_HOST environment variable.",
+)
+@click.option(
+    "--jira-issue-pattern",
+    required=False,
+    multiple=True,
+    help="Issue pattern to search the changlog for. Can be specified multiple times.",
+)
+@click.option(
+    "--jira-comment-template",
+    required=False,
+    default=None,
+    type=str,
+    help="JIRA comment template.",
+)
+@click.option(
+    "--fail",
+    is_flag=True,
+    help="Will fail if comments could not be added.",
+)
+@click.argument("version", type=str)
+def add_comments(
+    ctx,
+    version,
+    jira_username,
+    jira_password,
+    jira_host,
+    jira_issue_pattern,
+    jira_comment_template,
+    fail,
+):
+    """Will add comments to issues identified within the CHANGELOG. Currently supported systems are: [JIRA]"""
+    kacl_changelog = load_changelog(ctx)
+    kacl_config = kacl_changelog.config
+
+    if jira_host:
+        kacl_config.issue_tracker_jira_host = jira_host
+    if jira_username:
+        kacl_config.issue_tracker_jira_username = jira_username
+    if jira_password:
+        kacl_config.issue_tracker_jira_password = jira_password
+    if jira_issue_pattern:
+        kacl_config.issue_tracker_jira_issue_patterns = list(jira_issue_pattern)
+    if jira_comment_template:
+        kacl_config.issue_tracker_jira_comment_template = jira_comment_template
+
+    raise_on_invalid(kacl_changelog)
+
+    issues = kacl_changelog.get_associated_issues(version)
+    for issue_type in issues.keys():
+        click.secho(f"Found {len(issues[issue_type])} '{issue_type}' issues", fg="blue")
+        for issue in issues[issue_type]:
+            click.secho(f"{issue_type}: {issue}")
+
+    report = kacl_changelog.add_comments(version)
+
+    failed = False
+    for issue_type in report.keys():
+        for issue, success in report[issue_type].items():
+            if not success:
+                failed = True
+                click.secho(f"Failed to add comment to {issue_type}: {issue}", fg="red")
+
+    if fail and failed:
+        sys.exit(1)
+
+
 def start():
     try:
         cli(obj={})
